import allure

from service.app_t import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/relation/update")
def open_haohan_relation_update(userId=None, headers=None, **kwargs):
    """
    浩瀚模块-关联关系-Y
    up_time=1675665418

    params: userId :  : 用户ID（数据类型：String）
    params: headers : 请求头
    ====================返回======================
    """
    _method = "GET"
    _url = "/open/haohan/relation/update"

    _headers = {
    }
    _headers.update({"headers": headers})

    _data = {
        "userId": userId,  # 用户ID（数据类型：String）
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


