import allure

from service.app_t import http_requester
from huhk.unit_request import get_url


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


@allure.step(title="调接口：/open/haohan/rights/update")
def open_haohan_rights_update(params=None, headers=None, **kwargs):
    """
    浩瀚模块 - 更改充电桩权益状态-Y
    up_time=1675665629

    params: params : object : 
              data : string : 加密数据
    params: headers : 请求头
    ====================返回======================
    """
    _method = "POST"
    _url = "/open/haohan/rights/update"

    _headers = {
        "Content-Type": "application/json",
    }
    _headers.update({"headers": headers})

    _data = {
        "params": params,
    }

    _params = {
    }

    return http_requester(_method, _url, params=_params, data=_data, headers=_headers, **kwargs)


