from service.app_t.funs.open.haohan.funs_open_haohan_relation import FunsOpenHaohanRelation
from service.app_t.funs.open.haohan.funs_open_haohan_rights import FunsOpenHaohanRights


class FunsOpenHaohan(FunsOpenHaohanRelation, FunsOpenHaohanRights):
    pass

