from service.app_t.funs.points.funs_points_pointsApp import FunsPointsPointsapp
from service.app_t.funs.points.funs_points_points import FunsPointsPoints


class FunsPoints(FunsPointsPointsapp, FunsPointsPoints):
    pass

